@@ -282,6 +282,9 @@ void gcpAtom::Add(GtkWidget* w)
 			pango_context_set_font_description(pc, pData->View->GetPangoFontDesc());
 			gtk_text_buffer_get_iter_at_offset(m_buf, &start, index + 1);
 			gtk_text_buffer_insert_with_tags_by_name(m_buf, &start, hs, strlen(hs),pView->GetSmallFontName(), "subscript", NULL);
+			gtk_text_buffer_get_iter_at_offset(m_buf, &start, index + 1);
+			gtk_text_buffer_get_iter_at_offset(m_buf, &end, index + 1 + strlen (hs));
+			gtk_text_buffer_remove_tag_by_name(m_buf, pView->GetFontName(), &start, &end);
 			height += 2;
 		}
 		width = sw + hw + nw;
