@@ -24,6 +24,14 @@
  * USA
  */
 
+#include <mol.h>
+#undef PACKAGE
+#undef PACKAGE_BUGREPORT
+#undef PACKAGE_NAME
+#undef PACKAGE_STRING
+#undef PACKAGE_TARNAME
+#undef PACKAGE_VERSION
+#undef VERSION
 #include "config.h"
 #include "globals.h"
 #include "view.h"
@@ -102,7 +110,13 @@ const gchar* gcpDocument::GetLabel()
 void gcpDocument::SetFileName(const gchar* Name, const gchar* ext)
 {
 	if (m_filename) g_free(m_filename);
-	m_filename = g_strdup(Name);
+	if (*Name == '/') m_filename = g_strdup(Name);
+	else
+	{
+		gchar* curdir = g_get_current_dir();
+		m_filename = g_strconcat(curdir, "/", Name, NULL);
+		g_free(curdir);
+	}
 	int i = strlen(m_filename) - 1;
 	while ((m_filename[i] != '/') && (i >= 0)) i--;
 	if (i >=0) 
@@ -218,6 +232,7 @@ bool gcpDocument::ImportOB(OBMol& Mol)
 			AddBond(pBond);
 		}
 	}
+	ActivateMenu (FileMenu, SaveAsImageMenu, HasChildren ());
 	return true;
 }
 
@@ -232,7 +247,7 @@ void gcpDocument::BuildAtomTable(map<string, unsigned>& AtomTable, Object* obj,
 
 void gcpDocument::ExportOB()
 {
-	OBMol Mol(UNDEFINED, m_FileType);
+	OBMol Mol(UNDEFINED, (io_type) m_FileType);
 	map<string, unsigned>::iterator i;
 	map<string, unsigned> AtomTable;
 	list<gcpBond*> BondList;
@@ -529,6 +544,7 @@ bool gcpDocument::Load(xmlNodePtr root)
 		node = GetNextNodeByName(node->next, "text");
 	}
 	m_bIsLoading = false;
+	ActivateMenu (FileMenu, SaveAsImageMenu, HasChildren ());
 	return true;
 }
 	
@@ -805,6 +821,7 @@ void gcpDocument::OnUndo()
 	}
 	if (m_UndoList.empty())
 		ActivateMenu(EditMenu, UndoMenu, false);
+	ActivateMenu (FileMenu, SaveAsImageMenu, HasChildren ());
 	m_bUndoRedo = false;
 }
 
@@ -822,6 +839,7 @@ void gcpDocument::OnRedo()
 	}
 	if (m_RedoList.empty())
 		ActivateMenu(EditMenu, RedoMenu, false);
+	ActivateMenu (FileMenu, SaveAsImageMenu, HasChildren ());
 	m_bUndoRedo = false;
 }
 
@@ -836,6 +854,7 @@ void gcpDocument::FinishOperation()
 		m_RedoList.pop_front();
 	}
 	ActivateMenu(EditMenu, RedoMenu, false);
+	ActivateMenu (FileMenu, SaveAsImageMenu, HasChildren ());
 	m_pCurOp = NULL;
 }
 
@@ -912,6 +931,7 @@ void gcpDocument::LoadObjects(xmlNodePtr node)
 			Object* pObject = Object::CreateObject(str, this);
 			pObject->Load(child1); 
 			AddObject(pObject);
+			m_pView->Update(pObject);//FIXME: should not be necessary, but solve problem with cyclic double bonds
 			m_bIsLoading = false;
 		}
 		child = child->next;
