@@ -43,6 +43,7 @@
 #include "file.h"
 #include "globals.h"
 #include "gchempaint-bonobo.h"
+#include <gnome-vfs-module-2.0/libgnomevfs/gnome-vfs-mime.h>
 
 std::list<gcpDocument*> Docs;
 bool bCloseAll = false;
@@ -58,6 +59,7 @@ static GnomeApp *app;
 static GtkNotebook *book;
 static GtkMenu *windowsmenu;
 static GtkWidget* bar;	//GnomeAppBar
+static map<string, string> SupportedPixbufFormats;
 
 void on_change_element(int Z)
 {
@@ -318,6 +320,60 @@ static void on_prefs(GtkWidget* widget, void* data)
 	gtk_widget_destroy(GTK_WIDGET(dlg));*/
 }
 
+static bool do_save_as_image(GtkWidget* widget, GtkFileSelection *fsel)
+{
+	const gchar* filename = gtk_file_selection_get_filename(fsel);
+	if (!filename || !strlen(filename) || filename[strlen(filename) - 1] == '/') {
+		GtkWidget* message = gtk_message_dialog_new (GTK_WINDOW (fsel), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
+															_("Please enter a file name,\nnot a directory"));
+		gtk_dialog_run (GTK_DIALOG (message));
+		gtk_widget_destroy (message);
+		return true;
+	}
+	const char* mime_type = gnome_vfs_mime_type_from_name (filename);
+	if (SupportedPixbufFormats.find (mime_type) != SupportedPixbufFormats.end()) {
+		pActiveDoc->GetView ()->ExportImage (filename, SupportedPixbufFormats[mime_type].c_str ());
+		gtk_widget_destroy (GTK_WIDGET (fsel));
+		return false;
+	}
+	else if (!strcmp (mime_type, "image/x-eps")) {
+		char *result = NULL;
+		g_spawn_command_line_sync ("which ps2eps", &result, NULL, NULL, NULL);
+printf("result:%x\n",result);
+if (result) printf("result length:%x\n",strlen(result));
+		if (result && strlen (result)) {
+			pActiveDoc->GetView ()->ExportImage (filename, "eps");
+			gtk_widget_destroy (GTK_WIDGET (fsel));
+			g_free (result);
+			return false;
+		} else {
+			GtkWidget* message = gtk_message_dialog_new (GTK_WINDOW (fsel), GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, 
+																_("Please, install which and ps2eps!"));
+			gtk_dialog_run (GTK_DIALOG (message));
+			gtk_widget_destroy (message);
+		}
+		if (result)
+			g_free (result);
+	}
+	else {
+		GtkWidget* message = gtk_message_dialog_new (GTK_WINDOW (fsel), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
+															_("Sorry, format not supported!"));
+		gtk_dialog_run (GTK_DIALOG (message));
+		gtk_widget_destroy (message);
+	}
+	return true;
+}
+
+static void on_save_as_image(GtkWidget* widget, void* data)
+{
+	GtkFileSelection *fsel = GTK_FILE_SELECTION(gtk_file_selection_new("Save as Image"));
+	gtk_window_set_modal(GTK_WINDOW(fsel), true);
+	g_signal_connect(G_OBJECT(fsel->ok_button), "clicked", G_CALLBACK(do_save_as_image), fsel);
+	g_signal_connect_swapped(G_OBJECT(fsel->cancel_button), "clicked", G_CALLBACK(gtk_widget_destroy), fsel);
+	g_signal_connect(G_OBJECT(fsel), "destroy", G_CALLBACK(gtk_widget_destroy), NULL);
+	gtk_widget_show_all(GTK_WIDGET(fsel));
+}
+
 void on_about(GtkWidget* widget, void* data)
 {
 	char * authors[]={"Jean Bréfort",NULL};
@@ -331,7 +387,7 @@ Michał Sałaban: Polish"
 			);
 	GdkPixbuf* pixbuf = gdk_pixbuf_new_from_file ( DATADIR"/pixmaps/gchempaint_logo.png", NULL);
 	GtkWidget* about = gnome_about_new(_("GChemPaint"), VERSION,
-										_("(C) 2001-2003 by Jean Bréfort"),
+										_("(C) 2001-2004 by Jean Bréfort"),
 										_("GChemPaint is a 2D chemical structures editor for Gnome"),
 										(const gchar**) authors, (const gchar**) documentors, translators, pixbuf);
 	if (pixbuf != NULL)
@@ -381,6 +437,9 @@ static GnomeUIInfo file_menu [] = {
 	GNOMEUIINFO_MENU_OPEN_ITEM(on_file_open, NULL),
 	GNOMEUIINFO_MENU_SAVE_ITEM(on_file_save, NULL),
 	GNOMEUIINFO_MENU_SAVE_AS_ITEM(on_file_save_as, NULL),
+	{GNOME_APP_UI_ITEM, N_("Save as _Image"), N_("Save the current file as an image"),
+	(void*) on_save_as_image, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE_AS,
+	'I', (GdkModifierType) GDK_CONTROL_MASK, NULL},
 	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_MENU_PRINT_ITEM(on_print, NULL),
 	GNOMEUIINFO_SEPARATOR,
@@ -487,6 +546,22 @@ int main(int argc, char *argv[])
                    GNOME_PROGRAM_STANDARD_PROPERTIES, NULL);
 	g_object_get(G_OBJECT(prog), GNOME_PARAM_POPT_CONTEXT, &pctx, NULL);
 
+	GSList *formats = gdk_pixbuf_get_formats ();
+	GSList *l = formats;
+	GdkPixbufFormat *format;
+	char **mimes, **mime;
+	while (l) {
+		format = (GdkPixbufFormat*) l->data;
+		if (gdk_pixbuf_format_is_writable (format)) {
+			mimes = gdk_pixbuf_format_get_mime_types (format);
+			mime = mimes;
+			while (*mime)
+				SupportedPixbufFormats[*mime++] = gdk_pixbuf_format_get_name (format);
+			g_strfreev (mimes);
+		}
+		l = l->next;
+	}
+	g_slist_free (formats);
 
 	if (bonobo_server_flag)
 	{
@@ -514,6 +589,7 @@ int main(int argc, char *argv[])
 		ActivateMenu(EditMenu, CutMenu, false);
 		ActivateMenu(EditMenu, PasteMenu, false);
 		ActivateMenu(EditMenu, EraseMenu, false);
+		ActivateMenu(FileMenu, SaveAsImageMenu, false);
 		GladeXML* xml =  glade_xml_new(DATADIR"/gchempaint/glade/texttools.glade", "texttoolbar", NULL);
 		TextToolBar = glade_xml_get_widget(xml, "texttoolbar");
 //		gtk_toolbar_set_style(GTK_TOOLBAR(TextToolBar), GTK_TOOLBAR_ICONS);
