@@ -38,6 +38,7 @@
 #include "libgcpcanvas/gcp-canvas-group.h"
 #include <math.h>
 #include <pango/pango-context.h>
+#include <libgnomeprint/gnome-print-job.h>
 
 /*
 Derivation of a new widget from gnome_canvas with an event for updating canvas size
@@ -767,3 +768,54 @@ void gcpView::OnSelectAll()
 	m_pData->SelectAll();
 	SelectionTool.AddSelection(m_pData);
 }
+
+void gcpView::ExportImage (const char* filename, const char* type)
+{
+	ArtDRect rect;
+	m_pData->GetObjectBounds (m_pDoc, &rect);
+	int w = (int) (ceil (rect.x1) - floor (rect.x0)), h = (int) (ceil (rect.y1) - floor (rect.y0));
+	if (!strcmp (type, "eps")) {
+		GnomePrintConfig* config = gnome_print_config_default();
+		GnomePrintContext *pc;
+		GnomePrintJob *gpj = gnome_print_job_new (config);
+		pc = gnome_print_job_get_context (gpj);
+		gnome_print_beginpage(pc, (const guchar*)"");
+		gdouble width, height;
+		gnome_print_config_get_page_size(config, &width, &height);
+		Print(pc, width, height);
+		gnome_print_showpage(pc);
+		g_object_unref(pc);
+		gnome_print_job_close(gpj);
+		char *tmpname = g_strdup ("/tmp/gcp2epsXXXXXX");
+		int f = g_mkstemp (tmpname);
+		close (f);
+		gnome_print_config_set_boolean (config, (const guchar*) "Settings.Output.Job.PrintToFile", true);
+		gnome_print_config_set (config, (const guchar*) GNOME_PRINT_KEY_OUTPUT_FILENAME, (const guchar*) tmpname);
+		gnome_print_job_print (gpj);
+		g_object_unref (gpj);
+		gnome_print_config_unref(config);
+		char *command_line = g_strconcat ("ps2eps ", tmpname, NULL);
+		g_spawn_command_line_sync (command_line, NULL, NULL, NULL, NULL);
+		g_free (command_line);
+		command_line = g_strconcat ("mv -f ", tmpname, ".eps ", filename);
+		g_spawn_command_line_async (command_line, NULL);
+		remove (tmpname);
+		g_free (tmpname);
+		g_free (command_line);
+	} else {
+		gnome_canvas_update_now (GNOME_CANVAS (m_pWidget));
+		GdkDrawable *drawable = GDK_DRAWABLE (gtk_widget_get_parent_window (m_pWidget));
+		GdkPixbuf *pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, w, h);
+		GnomeCanvasBuf buf;
+		buf.buf = gdk_pixbuf_get_pixels (pixbuf);
+		buf.rect.x0 = (int) floor (rect.x0);
+		buf.rect.x1 = (int) ceil (rect.x1);
+		buf.rect.y0 = (int) floor (rect.y0);
+		buf.rect.y1 = (int) ceil (rect.y1);
+		buf.buf_rowstride = gdk_pixbuf_get_rowstride (pixbuf);
+		buf.bg_color = 0xffffff;
+		(* GNOME_CANVAS_ITEM_GET_CLASS (m_pData->Group)->render) (GNOME_CANVAS_ITEM (m_pData->Group), &buf);
+		gdk_pixbuf_save (pixbuf, filename, type, NULL, NULL);
+		g_object_unref (pixbuf);
+	}
+}
